@@ -7,9 +7,11 @@
 ## http://search.cpan.org/dist/Devel-NYTProf/
 ##
 ###########################################################
+## $Id$
+###########################################################
 package Devel::NYTProf;
 
-our $VERSION = '5.06'; # also change in Devel::NYTProf::Core
+our $VERSION = '5.01'; # also change in Devel::NYTProf::Core
 
 package    # hide the package from the PAUSE indexer
     DB;
@@ -180,7 +182,7 @@ statement executed in foo()>! Here's another example:
   }
 
 After the first time around the loop, any further time spent evaluating the
-condition (waiting for input in this example) would be recorded as having
+condition (waiting for input in this example) would be be recorded as having
 been spent I<on the last statement executed in the loop>! (Until perl bug
 #60954 is fixed this problem still applies to some loops. For more information
 see L<http://rt.perl.org/rt3/Ticket/Display.html?id=60954>)
@@ -308,12 +310,6 @@ a backslash.
 Append the current process id to the end of the filename.
 
 This avoids concurrent, or consecutive, processes from overwriting the same file.
-If a fork is detected during profiling then the child process will automatically
-add the process id to the filename.
-
-=head2 addtimestamp=1
-
-Append the current time, as integer epoch seconds, to the end of the filename.
 
 =head2 trace=N
 
@@ -541,19 +537,6 @@ When using the C<subs=0> option to disable the subroutine profiler the
 C<posix_exit> option can be used to tell NYTProf to take other steps to arrange
 for C<DB::finish_profile()> to be called before C<POSIX::_exit()>.
 
-=head2 libcexit=1
-
-Arranges for L</finish_profile> to be called via the C library C<atexit()> function.
-This may help some tricky cases where the process may exit without perl
-executing the C<END> block that NYTProf uses to call /finish_profile().
-
-=head2 endatexit=1
-
-Sets the PERL_EXIT_DESTRUCT_END flag in the PL_exit_flags of the perl interpreter.
-This makes perl run C<END> blocks in perl_destruct() instead of perl_run()
-which may help in cases, like Apache, where perl is embedded but perl_run()
-isn't called.
-
 =head2 forkdepth=N
 
 When a perl process that is being profiled executes a fork() the child process
@@ -603,9 +586,7 @@ to stop collecting profile data, and calling DB::enable_profile() to start
 collecting profile data.
 
 Using the C<start=no> option lets you leave the profiler disabled initially
-until you call DB::enable_profile() at the right moment. You still need to
-load Devel::NYTProf as early as possible, even if you don't call
-DB::enable_profile() until much later. See also L</use_db_sub=1>.
+until you call DB::enable_profile() at the right moment.
 
 The profile output file can't be used until it's been properly completed and
 closed.  Calling DB::disable_profile() doesn't do that.  To make a profile file
@@ -808,7 +789,7 @@ If you don't need statement-level profiling then you can disable it via L</stmts
 To further boost statement-level profiling performance try L</leave=0> but note that
 I<will> apportion timings for some kinds of statements less accurate).
 
-If you don't need call stacks or flamegraph then disable it via L</calls=0>.
+If you don't need calls stacks or flamegrph then disable it via L</calls=0>.
 If you don't need subroutine profiling then you can disable it via L</subs=0>.
 If you do need it but don't need timings for perl opcodes then set L</slowops=0>.
 
@@ -1080,8 +1061,6 @@ impacted by those more than it otherwise would.
 
 =head3 Windows
 
-B<THIS SECTION DOESN'T MATCH THE CODE>
-
 On Windows NYTProf uses Time::HiRes which uses the windows
 QueryPerformanceCounter() API with some extra logic to adjust for the current
 clock speed and try to resync the raw counter to wallclock time every so often
@@ -1135,10 +1114,6 @@ it's very likely to be deprecated in a future release).
 L<Devel::NYTProf::ReadStream> is the module that lets you read a profile data
 file as a stream of chunks of data.
 
-Other tools:
-
-DTrace L<https://speakerdeck.com/mrallen1/perl-dtrace-and-you>
-
 =head1 TROUBLESHOOTING
 
 =head2 "Profile data incomplete, ..." or "File format error: ..."
@@ -1233,7 +1208,7 @@ For more details see L</HISTORY> below.
 =head1 COPYRIGHT AND LICENSE
 
   Copyright (C) 2008 by Adam Kaplan and The New York Times Company.
-  Copyright (C) 2008-2013 by Tim Bunce, Ireland.
+  Copyright (C) 2008-2010 by Tim Bunce, Ireland.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
